:tocdepth: 3

.. _FBX Export MEL commands: https://help.autodesk.com/view/MAYAUL/2025/ENU/?guid=GUID-6CCE943A-2ED4-4CEE-96D4-9CB19C28F4E0
.. _FBX Export options: https://help.autodesk.com/view/MAYAUL/2025/ENU/?guid=GUID-FE8DBEAA-C2DD-43B3-9933-4BA4CDDEAA89
.. _FBX Import MEL commands: https://help.autodesk.com/view/MAYAUL/2025/ENU/?guid=GUID-699CDF74-3D64-44B0-967E-7427DF800290
.. _FBX Import options: https://help.autodesk.com/view/MAYAUL/2025/ENU/?guid=GUID-0CD41066-4C27-48AE-9776-366DB11B4FDF
.. _FBX Limitations: https://help.autodesk.com/view/MAYAUL/2025/ENU/?guid=GUID-AA3B8EA4-DDFB-4B0F-9654-2BF6B8781AE7
.. _Game Exporter: https://help.autodesk.com/view/MAYAUL/2025/ENU/?guid=GUID-2DB6E7B0-04B8-4585-91E9-7D64B02D0338

API Reference
=============

Official Maya documentation (2025):
   - `FBX Export MEL commands`_
   - `FBX Export options`_
   - `FBX Import MEL commands`_
   - `FBX Import options`_
   - `FBX Limitations`_
   - `Game Exporter`_

Export
------

.. autofunction:: mayafbx.export_fbx

.. autofunction:: mayafbx.restore_export_preset

.. autoclass:: mayafbx.FbxExportOptions
   :members:
   :undoc-members:
   :member-order: bysource
   :show-inheritance:

.. autonamedtuple:: mayafbx.utils.Take
   :members:

Import
------

.. autofunction:: mayafbx.import_fbx

.. autofunction:: mayafbx.restore_import_preset

.. autoclass:: mayafbx.FbxImportOptions
   :members:
   :undoc-members:
   :member-order: bysource
   :show-inheritance:

Bases
-----

.. autoclass:: mayafbx.FbxOptions
   :members:
   :undoc-members:

.. autoclass:: mayafbx.FbxProperty
   :members:
   :undoc-members:

.. autoclass:: mayafbx.FbxPropertyField
   :members:
   :undoc-members:

.. autotypevar:: mayafbx.bases.T


Enums
-----

.. autoclass:: mayafbx.AxisConversionMethod
   :members:
   :undoc-members:

.. autoclass:: mayafbx.ConvertUnit
   :members:
   :undoc-members:

.. autoclass:: mayafbx.FileFormat
   :members:
   :undoc-members:

.. autoclass:: mayafbx.FileVersion
   :members:
   :undoc-members:

.. autoclass:: mayafbx.ForcedFileAxis
   :members:
   :undoc-members:

.. autoclass:: mayafbx.MergeMode
   :members:
   :undoc-members:

.. autoclass:: mayafbx.NurbsSurfaceAs
   :members:
   :undoc-members:

.. autoclass:: mayafbx.QuaternionInterpolation
   :members:
   :undoc-members:

.. autoclass:: mayafbx.SamplingRate
   :members:
   :undoc-members:

.. autoclass:: mayafbx.SkeletonDefinition
   :members:
   :undoc-members:

.. autoclass:: mayafbx.UpAxis
   :members:
   :undoc-members:

